==> advert-1.0.13-sources.jar: com/yodo1/plugin/dmp/yodo1/open/Yodo1Analytics.java <==
package com.yodo1.plugin.dmp.yodo1.open;

import android.app.Activity;
import android.app.Application;

import com.yodo1.plugin.dmp.yodo1.constants.AnalyticsConst;
import com.yodo1.plugin.dmp.yodo1.helper.Yodo1AnalyticsForGA;
import com.yodo1.plugin.dmp.yodo1.helper.Yodo1AnalyticsForYodo1;
import com.yodo1.sdk.kit.YLog;

import java.util.HashMap;

/**
 * Created by zhuxiaochen on 2017/9/1.
 */

public class Yodo1Analytics {
    private static Yodo1AnalyticsForYodo1 helper = Yodo1AnalyticsForYodo1.getInstance();
    private static Yodo1AnalyticsForGA gaHelper = Yodo1AnalyticsForGA.getInstance();

    /**
     * Application初始化
     *
     * @param application
     */
    public static void createApp(Application application) {
        YLog.d("call Yodo1Analytics life cycle createApp ...");
        helper.onCreateApplication(application);
    }

    /**
     * 初始化SDK
     * @param appKey
     */
    public static void initSDK(Activity activity,String appKey) {
        YLog.i("call Yodo1Analytics life cycle initSDK ..." + appKey);
        helper.initSDK(activity,appKey);
    }

    public static void initGA(Activity activity){
        gaHelper.initSDK(activity);
    }

    //    /**
//     * 初始化SDK
//     * 请在使用其他接口之前，于onCreate中调用
//     *
//     * @param activity
//     */
//    public static void onCreate(Activity activity) {
//        YLog.d("call Yodo1Analytics life cycle onCreate ..." );
//        helper.onCreate(activity);
//    }
    public static void onResume(Activity activity) {
        YLog.d("call Yodo1Analytics life cycle onResume ...");
        helper.onResume(activity);
        gaHelper.onResume(activity);
    }

    public static void onPause(Activity activity) {
        YLog.d("call Yodo1Analytics life cycle onPause ...");
        helper.onPause(activity);
        gaHelper.onPause(activity);
    }

    public static void onDestroy(Activity activity) {
        gaHelper.onDestroy();
    }

    public static void onEvent(String eventId, String advertCode , String showResult) {
        YLog.d("call Yodo1Analytics life cycle onEvent ...  " + eventId + "  " + advertCode + "  " + showResult);
        HashMap<String, Object> map = new HashMap<String,Object>();
        map.put(AnalyticsConst.AdvertCode,advertCode);
        map.put(AnalyticsConst.Result,showResult);

        helper.onEvent(eventId,map);
        gaHelper.onEvent(eventId,map);
    }

}

==> advert-1.1.2-sources.jar: com/yodo1/plugin/dmp/yodo1/open/Yodo1Analytics.java <==
package com.yodo1.plugin.dmp.yodo1.open;

import android.app.Activity;
import android.app.Application;

import com.yodo1.plugin.dmp.yodo1.constants.AnalyticsConst;
import com.yodo1.plugin.dmp.yodo1.helper.Yodo1AnalyticsForGA;
import com.yodo1.plugin.dmp.yodo1.helper.Yodo1AnalyticsForYodo1;
import com.yodo1.plugin.dmp.yodo1.helper.Yodo1AnalyticsManage;
import com.yodo1.sdk.kit.YLog;

import java.util.HashMap;

/**
 * Created by zhuxiaochen on 2017/9/1.
 */

public class Yodo1Analytics {
    private static Yodo1AnalyticsForYodo1 helper = Yodo1AnalyticsForYodo1.getInstance();
    private static Yodo1AnalyticsForGA gaHelper = Yodo1AnalyticsForGA.getInstance();
    private static Yodo1AnalyticsManage manage = Yodo1AnalyticsManage.getInstance();

    /**
     * Application初始化
     *
     * @param application
     */
    public static void createApp(Application application) {
        YLog.d("call Yodo1Analytics life cycle createApp ...");
        helper.onCreateApplication(application);
    }

    /**
     * 初始化SDK
     * @param appKey
     */
    public static void initSDK(Activity activity,String appKey) {
        YLog.i("call Yodo1Analytics life cycle initSDK ..." + appKey);;
        manage.initSDK(activity,appKey);
    }

    //    /**
//     * 初始化SDK
//     * 请在使用其他接口之前，于onCreate中调用
//     *
//     * @param activity
//     */
//    public static void onCreate(Activity activity) {
//        YLog.d("call Yodo1Analytics life cycle onCreate ..." );
//        helper.onCreate(activity);
//    }
    public static void onResume(Activity activity) {
        YLog.d("call Yodo1Analytics life cycle onResume ...");
        manage.onResume(activity);
    }

    public static void onPause(Activity activity) {
        YLog.d("call Yodo1Analytics life cycle onPause ...");
        manage.onPause(activity);
    }

    public static void onDestroy() {
        manage.onDestroy();
        YLog.e("an  onDestroy ");
    }

    public static void onEvent(String eventId, String advertCode , String showResult) {
        YLog.d("call Yodo1Analytics life cycle onEvent ...  " + eventId + "  " + advertCode + "  " + showResult);
        HashMap<String, Object> map = new HashMap<String,Object>();
        map.put(AnalyticsConst.AdvertCode,advertCode);
        map.put(AnalyticsConst.Result,showResult);

        helper.onEvent(eventId,map);
        gaHelper.onEvent(eventId,map);
    }

}
